# Copyright 2014 IBM Corp.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from zaqarclient.queues import client

URL = 'http://localhost:8888'


def healthy():
    # Note: credential information should be provided
    # using `conf` keyword argument if authentication
    # is enabled at server side. Please refer to
    # keystone_auth.py for more information.
    cli = client.Client(url=URL, version=2)
    return True if cli.health() else False


if __name__ == '__main__':
    healthy()
